@@ -5,6 +5,7 @@ from django.db import models
 from django.urls import reverse
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
+from django.template.loader import render_to_string
 
 from ..decorators import modify_fields
 from .abstract_base_page_translation import AbstractBasePageTranslation
@@ -94,24 +95,83 @@ class PageTranslation(AbstractBasePageTranslation):
             "public:expand_page_translation_id", kwargs={"short_url_id": self.id}
         )
 
+    @cached_property
+    def mirrored_translation_text(self):
+        """
+        This method returns the text of the mirrored translation.
+        If there is no mirrored translation, it returns an empty string.
+        If there is a mirrored page but no translation, a html error message will be returned with languages that are translated as options.
+
+        :return: The text, as specified
+        :rtype: str
+        """
+        if not self.page.mirrored_page:
+            return ""
+
+        translation = self.page.get_mirrored_page_translation(self.language.slug)
+        if translation and translation.content:
+            return translation.content
+
+        error_message = (
+            self.language.message_partial_live_content_not_available
+            if self.content and not self.content.isspace()
+            else self.language.message_content_not_available
+        )
+
+        # Get all translations of this page which have a corresponding translation of the mirrored page
+        translations = filter(
+            None,
+            [
+                self.page.get_public_translation(language_slug)
+                for language_slug in self.page.mirrored_page.prefetched_major_public_translations_by_language_slug.keys()
+            ],
+        )
+        return render_to_string(
+            "pages/_page_content_alternatives.html",
+            {"error_message": error_message, "translations": translations},
+        )
+
+    @cached_property
+    def display_content(self):
+        """
+        This property returns the content that can be displayed to the user.
+        This is just the normal content unless this translation is empty. Then a message will be returned
+        which prompts the user to view the page in another language instead.
+
+        :return: Html text for the content of this translation
+        :rtype: str
+        """
+        if self.content and not self.content.isspace() or self.page.mirrored_page:
+            return self.content
+
+        fallback_translations = [
+            translation
+            for translation in self.page.prefetched_public_translations_by_language_slug.values()
+            if translation.content and not translation.content.isspace()
+        ]
+        return render_to_string(
+            "pages/_page_content_alternatives.html",
+            {
+                "error_message": self.language.message_content_not_available,
+                "translations": fallback_translations,
+            },
+        )
+
     @cached_property
     def combined_text(self):
         """
         This function combines the text from this PageTranslation with the text from the mirrored page.
         Mirrored content always includes the live content from another page. This content needs to be added when
         delivering content to end users.
+        If the mirrored page is not available in the current language, or if the content is empty,
+        an error message for the user will be used instead.
 
         :return: The combined content of this page and the mirrored page
         :rtype: str
         """
-        mirrored_page_translation = self.page.get_mirrored_page_translation(
-            self.language.slug
-        )
-        if not mirrored_page_translation or not mirrored_page_translation.content:
-            return self.content
         if self.page.mirrored_page_first:
-            return mirrored_page_translation.content + self.content
-        return self.content + mirrored_page_translation.content
+            return self.mirrored_translation_text + self.display_content
+        return self.display_content + self.mirrored_translation_text
 
     @cached_property
     def combined_last_updated(self):
@@ -134,6 +194,21 @@ class PageTranslation(AbstractBasePageTranslation):
             return mirrored_page_translation.last_updated
         return self.last_updated
 
+    @cached_property
+    def is_empty(self):
+        """
+        This property returns whether the content of this translation is empty
+
+        :return: Whether the content of this translation is empty
+        :rtype: bool
+        """
+        if self.content:
+            return False
+
+        # The translation is considered empty when its mirrored translation is empty or does not exist
+        translation = self.page.get_mirrored_page_translation(self.language.slug)
+        return not translation or not translation.content
+
     @cached_property
     def tags(self):
         """
@@ -150,7 +225,7 @@ class PageTranslation(AbstractBasePageTranslation):
         if self.page.mirrored_page:
             tags.append(_("Live content"))
 
-        if not self.combined_text.strip() and self.page.is_leaf():
+        if self.is_empty and self.page.is_leaf():
             tags.append(_("Empty"))
 
         return tags
