@@ -5,7 +5,14 @@ Views which should not have login protection go into :mod:`~integreat_cms.cms.ur
 """
 from django.urls import include, path
 
-from ..forms import LanguageForm, OfferTemplateForm, OrganizationForm, RegionForm
+from ..forms import (
+    LanguageForm,
+    OfferTemplateForm,
+    OrganizationForm,
+    RegionForm,
+    EventTranslationForm,
+    POITranslationForm,
+)
 from ..models import Event, Language, OfferTemplate, Organization, Page, POI, Role
 
 from ..views import (
@@ -179,7 +186,7 @@ urlpatterns = [
                     name="new_region",
                 ),
                 path(
-                    "<slug:slug>/",
+                    "<slug>/",
                     include(
                         [
                             path(
@@ -309,7 +316,7 @@ urlpatterns = [
                     name="new_organization",
                 ),
                 path(
-                    "<slug:slug>/",
+                    "<slug>/",
                     include(
                         [
                             path(
@@ -431,7 +438,7 @@ urlpatterns = [
         ),
     ),
     path(
-        "<slug:region_slug>/",
+        "<region_slug>/",
         include(
             [
                 path("", dashboard.DashboardView.as_view(), name="dashboard"),
@@ -440,14 +447,65 @@ urlpatterns = [
                     include(
                         [
                             path("", include(media_ajax_urlpatterns)),
+                            path(
+                                "<slug:language_slug>/",
+                                include(
+                                    [
+                                        path(
+                                            "<int:page_id>/",
+                                            include(
+                                                [
+                                                    path(
+                                                        "cancel-translation-process/",
+                                                        pages.cancel_translation_process_ajax,
+                                                        name="cancel_translation_process_ajax",
+                                                    ),
+                                                    path(
+                                                        "preview/",
+                                                        pages.preview_page_ajax,
+                                                        name="preview_page_ajax",
+                                                    ),
+                                                    path(
+                                                        "content/",
+                                                        pages.get_page_content_ajax,
+                                                        name="get_page_content_ajax",
+                                                    ),
+                                                ]
+                                            ),
+                                        ),
+                                        path(
+                                            "search/",
+                                            utils.search_content_ajax,
+                                            name="search_content_ajax",
+                                        ),
+                                        path(
+                                            "<model_type>/slugify/",
+                                            utils.slugify_ajax,
+                                            name="slugify_ajax",
+                                        ),
+                                    ]
+                                ),
+                            ),
                             path(
                                 "render/",
                                 include(
                                     [
                                         path(
-                                            "mirrored-page-field/",
-                                            pages.render_mirrored_page_field,
-                                            name="render_mirrored_page_field",
+                                            "<slug:language_slug>/",
+                                            include(
+                                                [
+                                                    path(
+                                                        "mirrored-page-field/",
+                                                        pages.render_mirrored_page_field,
+                                                        name="render_mirrored_page_field",
+                                                    ),
+                                                    path(
+                                                        "partial-page-tree/tree-<int:tree_id>/",
+                                                        pages.PartialPageTreeView.as_view(),
+                                                        name="get_page_tree_ajax",
+                                                    ),
+                                                ]
+                                            ),
                                         ),
                                         path(
                                             "page-order-table/",
@@ -468,11 +526,6 @@ urlpatterns = [
                                                 ]
                                             ),
                                         ),
-                                        path(
-                                            "partial-page-tree/<slug:language_slug>/tree-<int:tree_id>/",
-                                            pages.PartialPageTreeView.as_view(),
-                                            name="get_page_tree_ajax",
-                                        ),
                                     ]
                                 ),
                             ),
@@ -528,30 +581,32 @@ urlpatterns = [
                                 ),
                             ),
                             path(
-                                "cancel-translation-process/<slug:language_slug>/<int:page_id>/",
-                                pages.cancel_translation_process_ajax,
-                                name="cancel_translation_process_ajax",
+                                "content-edit-lock/",
+                                include(
+                                    [
+                                        path(
+                                            "heartbeat/",
+                                            utils.content_edit_lock_heartbeat,
+                                            name="content_edit_lock_heartbeat",
+                                        ),
+                                        path(
+                                            "release/",
+                                            utils.content_edit_lock_release,
+                                            name="content_edit_lock_release",
+                                        ),
+                                    ]
+                                ),
                             ),
                             path(
                                 "search-poi/",
                                 events.search_poi_ajax,
                                 name="search_poi_ajax",
                             ),
-                            path(
-                                "<slug:language_slug>/search/",
-                                utils.search_content_ajax,
-                                name="search_content_ajax",
-                            ),
                             path(
                                 "search/",
                                 utils.search_content_ajax,
                                 name="search_content_ajax",
                             ),
-                            path(
-                                "<slug:language_slug>/<model_type>/slugify/",
-                                utils.slugify_ajax,
-                                name="slugify_ajax",
-                            ),
                             path(
                                 "dismiss-tutorial/<slug:slug>/",
                                 settings.DismissTutorial.as_view(),
@@ -590,8 +645,20 @@ urlpatterns = [
                                         ),
                                         path(
                                             "<slug:link_filter>/",
-                                            linkcheck.LinkListView.as_view(),
-                                            name="linkcheck",
+                                            include(
+                                                [
+                                                    path(
+                                                        "",
+                                                        linkcheck.LinkListView.as_view(),
+                                                        name="linkcheck",
+                                                    ),
+                                                    path(
+                                                        "<int:link_id>/",
+                                                        linkcheck.LinkListView.as_view(),
+                                                        name="edit_link",
+                                                    ),
+                                                ]
+                                            ),
                                         ),
                                     ]
                                 ),
@@ -680,11 +747,6 @@ urlpatterns = [
                                             "<int:page_id>/",
                                             include(
                                                 [
-                                                    path(
-                                                        "view/",
-                                                        pages.view_page,
-                                                        name="view_page",
-                                                    ),
                                                     path(
                                                         "edit/",
                                                         include(
@@ -835,7 +897,7 @@ urlpatterns = [
                                         path(
                                             "auto-translate/",
                                             bulk_action_views.BulkAutoTranslateView.as_view(
-                                                model=Event
+                                                model=Event, form=EventTranslationForm
                                             ),
                                             name="automatic_translation_events",
                                         ),
@@ -918,7 +980,7 @@ urlpatterns = [
                                         path(
                                             "auto-translate/",
                                             bulk_action_views.BulkAutoTranslateView.as_view(
-                                                model=POI
+                                                model=POI, form=POITranslationForm
                                             ),
                                             name="automatic_translation_pois",
                                         ),
