@@ -10,19 +10,23 @@ from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext as _
 from django.views.generic import TemplateView
 
+from ...constants import status
 from ...decorators import permission_required
 from ...forms import POIForm, POITranslationForm
 from ...models import POI, POITranslation, Language
-from .poi_context_mixin import POIContextMixin
+from ...utils.translation_utils import ugettext_many_lazy as __
 from ..media.media_context_mixin import MediaContextMixin
-from ...constants import status
+from ..mixins import ContentEditLockMixin
+from .poi_context_mixin import POIContextMixin
 
 logger = logging.getLogger(__name__)
 
 
 @method_decorator(permission_required("cms.view_poi"), name="dispatch")
 @method_decorator(permission_required("cms.change_poi"), name="post")
-class POIFormView(TemplateView, POIContextMixin, MediaContextMixin):
+class POIFormView(
+    TemplateView, POIContextMixin, MediaContextMixin, ContentEditLockMixin
+):
     """
     View for editing POIs
     """
@@ -31,6 +35,8 @@ class POIFormView(TemplateView, POIContextMixin, MediaContextMixin):
     template_name = "pois/poi_form.html"
     #: The context dict passed to the template (see :class:`~django.views.generic.base.ContextMixin`)
     extra_context = {"current_menu_item": "pois_form"}
+    #: The url name of the view to show if the user decides to go back (see :class:`~integreat_cms.cms.views.mixins.ContentEditLockMixin`)
+    back_url_name = "pois"
 
     def get(self, request, *args, **kwargs):
         r"""
@@ -142,6 +148,7 @@ class POIFormView(TemplateView, POIContextMixin, MediaContextMixin):
                 "language": language,
                 "poi": poi_form.instance,
             },
+            changed_by_user=request.user,
         )
 
         if not poi_form.is_valid() or not poi_translation_form.is_valid():
@@ -171,6 +178,17 @@ class POIFormView(TemplateView, POIContextMixin, MediaContextMixin):
             else:
                 # Add the success message
                 poi_translation_form.add_success_message(request)
+            # Show warning if nominatim result is more than 10km away from manually entered coordinates
+            if poi_form.nominatim_distance_delta > 10:
+                messages.warning(
+                    request,
+                    __(
+                        _(
+                            "The distance between the manually entered coordinates and the coordinates of the address is {}km."
+                        ).format(poi_form.nominatim_distance_delta),
+                        _("Please make sure the entered values are correct."),
+                    ),
+                )
             return redirect(
                 "edit_poi",
                 **{
