@@ -12,6 +12,7 @@ import os
 from distutils.util import strtobool
 from urllib.parse import urlparse
 
+from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 
 from .logging_formatter import ColorFormatter
@@ -74,6 +75,24 @@ AUTHOR_CHAT_HISTORY_DAYS = 30
 #: The time span up to which recurrent events should be returned by the api
 API_EVENTS_MAX_TIME_SPAN_DAYS = 31
 
+#: The company operating this CMS
+COMPANY = os.environ.get("INTEGREAT_CMS_COMPANY", "Tür an Tür – Digitalfabrik gGmbH")
+
+#: The URL to the company's website
+COMPANY_URL = os.environ.get(
+    "INTEGREAT_CMS_COMPANY_URL", "https://tuerantuer.de/digitalfabrik/"
+)
+
+#: The available inbuilt brandings of the CMS
+AVAILABLE_BRANDINGS = ["integreat", "malte", "aschaffenburg"]
+
+#: The branding of the CMS
+BRANDING = os.environ.get("INTEGREAT_CMS_BRANDING", "integreat")
+
+if BRANDING not in AVAILABLE_BRANDINGS:
+    raise ImproperlyConfigured(
+        f"The branding {BRANDING!r} is not supported, must be one of {AVAILABLE_BRANDINGS}."
+    )
 
 ###############################
 # Firebase Push Notifications #
@@ -100,6 +119,23 @@ GVZ_API_ENABLED = True
 GVZ_API_URL = "https://gvz.integreat-app.de"
 
 
+#################
+# Nominatim API #
+#################
+
+#: Whether or not the Nominatim API for OpenStreetMap queries is enabled.
+#: This is used to automatically derive coordinates from addresses.
+NOMINATIM_API_ENABLED = bool(
+    strtobool(os.environ.get("INTEGREAT_CMS_NOMINATIM_API_ENABLED", "True"))
+)
+
+#: The URL to our Nominatim API.
+#: This is used to automatically derive coordinates from addresses.
+NOMINATIM_API_URL = os.environ.get(
+    "INTEGREAT_CMS_NOMINATIM_API_URL", "http://nominatim.maps.tuerantuer.org/nominatim/"
+)
+
+
 ############
 # WEBAUTHN #
 ############
@@ -138,6 +174,7 @@ INSTALLED_APPS = [
     # Installed custom apps
     "integreat_cms.cms",
     "integreat_cms.gvz_api",
+    "integreat_cms.deepl_api",
     "integreat_cms.linkcheck.apps.ModifiedLinkcheckConfig",
     # Installed Django apps
     "django.contrib.auth",
@@ -178,7 +215,7 @@ MIDDLEWARE = [
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "integreat_cms.core.middleware.RegionMiddleware",
     "integreat_cms.core.middleware.AccessControlMiddleware",
-    "integreat_cms.cms.middleware.TimezoneMiddleware",
+    "integreat_cms.core.middleware.TimezoneMiddleware",
 ]
 
 # The Django debug toolbar middleware will only be activated if the debug_toolbar app is installed
@@ -204,6 +241,7 @@ TEMPLATES = [
                 "django.contrib.messages.context_processors.messages",
                 "integreat_cms.core.context_processors.version_processor",
                 "integreat_cms.core.context_processors.push_notification_processor",
+                "integreat_cms.core.context_processors.branding_processor",
             ],
             "debug": DEBUG,
         },
@@ -303,8 +341,9 @@ AUTH_USER_MODEL = "cms.User"
 #: A list of authentication backend classes (as strings) to use when attempting to authenticate a user
 #: (see :setting:`django:AUTHENTICATION_BACKENDS` and :ref:`django:authentication-backends`)
 AUTHENTICATION_BACKENDS = (
-    "rules.permissions.ObjectPermissionBackend",
-    "django.contrib.auth.backends.ModelBackend",  # this is default
+    "rules.permissions.ObjectPermissionBackend",  # Object-based permission checks
+    "django.contrib.auth.backends.ModelBackend",  # Login via username
+    "integreat_cms.core.authentication_backends.EmailAuthenticationBackend",  # Login via email
 )
 
 PASSWORD_HASHERS = [
@@ -326,13 +365,13 @@ AUTH_PASSWORD_VALIDATORS = [
 ]
 
 #: The URL where requests are redirected for login (see :setting:`django:LOGIN_URL`)
-LOGIN_URL = "/login"
+LOGIN_URL = "/login/"
 
 #: The URL where requests are redirected after login (see :setting:`django:LOGIN_REDIRECT_URL`)
 LOGIN_REDIRECT_URL = "/"
 
 #: The URL where requests are redirected after logout (see :setting:`django:LOGOUT_REDIRECT_URL`)
-LOGOUT_REDIRECT_URL = "/login"
+LOGOUT_REDIRECT_URL = "/login/"
 
 
 ###########
@@ -446,6 +485,10 @@ LOGGING = {
             "handlers": ["console", "logfile"],
             "level": DEPS_LOG_LEVEL,
         },
+        "deepl": {
+            "handlers": ["console", "logfile"],
+            "level": DEPS_LOG_LEVEL,
+        },
         "django": {
             "handlers": ["console", "logfile"],
             "level": DEPS_LOG_LEVEL,
@@ -637,18 +680,10 @@ LEGACY_FILE_UPLOAD = bool(
 
 #: Configuration for caches (see :setting:`django:CACHES` and :doc:`django:topics/cache`).
 #: Use a ``LocMemCache`` for development and a ``RedisCache`` whenever available.
-#: Additionally, a ``FileBasedCache`` is used for PDF caching.
 CACHES = {
     "default": {
         "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
     },
-    "pdf": {
-        "BACKEND": "django.core.cache.backends.filebased.FileBasedCache",
-        "LOCATION": os.path.join(
-            os.environ.get("INTEGREAT_CMS_FILE_CACHE", os.path.join(BASE_DIR, "cache")),
-            "pdf",
-        ),
-    },
 }
 
 # Use RedisCache when activated
@@ -748,6 +783,17 @@ DEBUG_TOOLBAR_PANELS = [
 ]
 
 
+##############
+# PDF EXPORT #
+##############
+
+#: The directory where PDF files are stored
+PDF_ROOT = os.environ.get("INTEGREAT_CMS_PDF_ROOT", os.path.join(BASE_DIR, "pdf"))
+
+#: The URL path where PDF files are served for download
+PDF_URL = "/pdf/"
+
+
 #######################
 # XLIFF SERIALIZATION #
 #######################
