@@ -408,6 +408,7 @@ def xliff_import_confirm(request, xliff_dir):
 def get_xliff_import_errors(request, page_translation, add_message_if_unchanged=False):
     """
     Validate an imported page translation and return all errors
+    As a side effect, a unique slug is generated for the translation if it does not yet have one.
 
     :param request: The current request (used for error messages)
     :type request: ~django.http.HttpRequest
@@ -473,6 +474,9 @@ def get_xliff_import_errors(request, page_translation, add_message_if_unchanged=
                 for message in page_translation_form.get_error_messages()
             ]
         )
+    else:
+        # Use the unique slug generated by the form's clean-method for imported page translations
+        page_translation.slug = page_translation_form.instance.slug
     if add_message_if_unchanged:
         if not page_translation_form.has_changed():
             error_messages.append(
