@@ -282,6 +282,7 @@ VIEWS = [
                     "status": "ACTIVE",
                     "longitude": 1,
                     "latitude": 1,
+                    "timezone": "Europe/Berlin",
                 },
             ),
         ],
@@ -302,6 +303,8 @@ VIEWS = [
                     "text_direction": "LEFT_TO_RIGHT",
                     "table_of_contents": "Inhaltsverzeichnis",
                     "primary_country_code": "de",
+                    "message_content_not_available": "Foo1",
+                    "message_partial_live_content_not_available": "Foo2",
                 },
             ),
         ],
@@ -405,7 +408,6 @@ VIEWS = [
     ),
     (
         [
-            ("view_page", STAFF_ROLES + [MANAGEMENT, EDITOR]),
             ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR]),
             ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR]),
             (
@@ -438,7 +440,6 @@ VIEWS = [
     ),
     (
         [
-            ("view_page", STAFF_ROLES),
             ("edit_page", STAFF_ROLES),
             ("sbs_edit_page", STAFF_ROLES),
             ("page_revisions", STAFF_ROLES),
